code	segment	'code'
	assume	cs:code,ds:code

	org	100h

start:	mov	ax,ds:[0082h]		; read digits in command tail

	cmp	al,'1'			; ensure first digit is 1-9
	jl	badp
	cmp	al,'9'
	jg	badp
	sub	al,'0'			; convert to number

	xchg	ah,al			; second digit?
	cmp	al,' '			; space is terminator
	je	term
	cmp	al,0dh			; CR is terminator
	je	term

	cmp	al,'0'			; ensure second digit is 0-9
	jl	badp
	cmp	al,'9'
	jg	badp
	sub	al,'0'			; convert to number

	xchg	ah,al			; restore digit order
	jmp	calc

term:	xor	al,al			; zero 10s for single digit

calc:	xor	bx,bx			; zero work registers
	xor	cx,cx

	xchg	ah,cl			; move 1s out of AX
	mov	bl,10			; multiply 10s by 10
	imul	bx
	add	al,cl			; add 1s

	mov	dvsr,ax			; store rate divisor

	mov	sp,02feh		; move stack pointer

	mov	bx,30h			; resize memory block
	mov	ah,4ah
	int	21h

	mov	ax,3533h		; get current INT 33h handler
	int	21h
	mov	word ptr old33,bx
	mov	word ptr old33+2,es
	push	cs			; restore ES for EXEC
	pop	es

	mov	dx,offset new33		; install new INT 33h handler
	mov	ah,25h
	int	21h

	mov	word ptr tail+2,cs	; set segments in param block
	mov	word ptr fcb1+2,cs
	mov	word ptr fcb2+2,cs

	mov	dx,offset prog		; EXEC child process
	mov	bx,offset parm
	mov	ax,4b00h
	int	21h

	mov	dx,word ptr old33	; restore old INT 33h handler
	mov	ds,word ptr old33+2
	mov	ax,2533h
	int	21h

exit:	mov	ax,4c00h		; exit to DOS
	int	21h

badp:	mov	dx,offset pmsg		; display parameter message
	mov	ah,09h
	int	21h
	jmp	exit

new33:	cmp	ax,0004h		; position function?
	jne	pass
	cmp	cx,320			; centered X coord?
	jne	pass
	cmp	dx,240			; centered Y coord?
	jne	pass

	dec	cs:cntr			; allow centering only at 0
	je	allow
	iret				; drop centering

allow:	push	cs:dvsr			; reload counter with divisor
	pop	cs:cntr
pass:
	db	0eah			; far jump opcode
old33	dd	0			; old INT 33h handler address

cntr	dw	1			; allow first centering
dvsr	dw	1			; rate divisor
pmsg	db	'Parameter = 1-99$'	; parameter message
prog	db	'ATLDOS.EXE',0		; program filename
line	db	0,0dh			; command line tail

parm	dw	0			; default env seg
tail	dd	offset line		; command line tail pointer
fcb1	dd	5ch			; first FCB pointer
fcb2	dd	6ch			; second FCB pointer

code	ends

	end	start
